# package_name

`rockoto` is a Python library for Rocket,Circle and Shuffle

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install `rockoto`.

```bash
pip install rockoto
```

## Usage

```python
import rocket

# returns 'words'
rockoto.module_name('word')

# returns 'geese'
rockoto.module_name('goose')

# returns 'phenomenon'
rockoto.module_name('phenomena')
```

## License

[MIT](https://choosealicense.com/licenses/mit/)
